#!/bin/bash
# -----------------------------------------------------------------------------
# secure-properties.sh - Start the encrypt utility to secure configuration properties
#
# This script is provided to start the OneLogin secure properties utility
# in Linux/Unix/Mac OSX environments. It works as follows:
#
# 1. Checks for and validates the LDC_HOME environment, which must reference
#    the directory where the OneLogin secure properties utility is installed.
#    Other directories, including: bin, conf, logs are expected to be direct
#    child directories below LDC_HOME.
#
# 2. If LDC_HOME is not set, it attempts to find it relative to the current
#    working directory or the immediate parent directory.
#
# 3. Constructs the path to the LDAP Directory Connector jar file at:
#    LDC_HOME/libs/onelogin-ldc.jar
#    and ensure it exists.
#
# 4. Checks If SECURE_PASSWORD is set, this will be used to encrypt the properties.
#
# 5. Constructs command line options.
#
# 6. Launches the JVM on the OneLogin secure properties utility.
#
# This utility generates encrypted configuration values to be added to the ldc.conf configuration file
# -----------------------------------------------------------------------------
#

#--- Uncomment to enable shell debugging
#set -x

#--- The Java JAR file containing LDAP Directory Connector executable code
#
JAR_FILE_NAME="onelogin-ldc.jar"

#--- Check for or set the LDAP Connector Home directory
if [ ! -z "${LDC_HOME}" ]; then
	if [ ! -d ${LDC_HOME} ] ; then
		echo "[FATAL] - the LDC_HOME value (${LDC_HOME}) is not a valid directory path"
		echo "          1. Check the environment value of LDC_HOME"
		echo "          2. Ensure the directory exists, is readable and contains the 'libs' directory"
		echo "             containing the ${JAR_FILE_NAME} file"
		exit 1
	fi
elif [ -f ./libs/${JAR_FILE_NAME} ]; then
	LDC_HOME=.
elif [ -f ../libs/${JAR_FILE_NAME} ]; then
	LDC_HOME=..
else
	echo "[FATAL] - the LDC_HOME value is not set and could not be guessed"
	echo "          1. Set LDC_HOME value to your LDAP Directory Connector installation directory"
	echo "             Example: export LDC_HOME=/usr/local/onelogin-ldc-2.2.12"
	echo "          2. or invoke this script from the directory where you installed the LDAP Directory Connector"
	echo "             Example: cd /usr/local/onelogin-ldc-2.2.12; ./bin/secure-properties.sh"
	echo "          3. or invoke this script from the directory containing this script"
	echo "             Example: cd /usr/local/onelogin-ldc-2.2.12/bin; ./secure-properties.sh"
	exit 1
fi

#--- Check for the executable JAR file
JAR_PATH="${LDC_HOME}/libs/${JAR_FILE_NAME}"
if [ ! -f ${JAR_PATH} ] ; then
	echo "[FATAL] - LDAP Directory Connector jar file not found at: $JAR_PATH"
	echo "          1. Check the value of LDC_HOME (in your environment or in this script)"
	exit 1
fi

#--- Check for SECURE_PASSWORD variable
LDC_CONFIG_PASSWORD=""
if [ -z "$SECURE_PASSWORD" ] ; then
  echo "[FATAL] - environment variable SECURE_PASSWORD is not defined, define variable to start."
  exit 1
else
  LDC_CONFIG_PASSWORD="-p ${SECURE_PASSWORD}"
fi

#--- Confirm the Java Runtime Environment (JRE) is installed
JVM_MIN_VERSION=8
JVM_PATH=`which java`
if [ -z "${JVM_PATH}" ]; then
	echo "[FATAL] - java command not found"
	echo "          Configure your PATH or install Java version ${JVM_MIN_VERSION} or greater"
	echo "          Download from http://www.oracle.com/technetwork/java/javase/downloads/index.html"
	exit 1
fi

#--- Verify the JRE Version
JVM_VERSION=$(java -version 2>&1 | grep -i version | sed 's/.*version ".*\.\(.*\)\..*"/\1/; 1q')
if [ ${JVM_VERSION} -lt ${JVM_MIN_VERSION} ]; then
	echo "[FATAL] - Java Runtime Environment ${JVM_VERSION} is not supported."
	echo "          Minimum JRE version supported is ${JVM_MIN_VERSION}"
	echo "          Download from http://www.oracle.com/technetwork/java/javase/downloads/index.html"
	exit 1
fi

echo "[INFO] - Starting the OneLogin LDAP Connector Secure Properties Utility using command:"
echo "java -cp ${JAR_PATH} com.onelogin.ldc.console.SecureProperties ${LDC_CONFIG_PASSWORD}"
java -cp ${JAR_PATH} com.onelogin.ldc.console.SecureProperties ${LDC_CONFIG_PASSWORD}

#
#--- EOF
