#!/bin/bash
# -----------------------------------------------------------------------------
# start-ldc.sh - Start the OneLogin LDAP Directory Connector version 2
#
# This script is provided to start the OneLogin LDAP Directory Connector
# version 2 in Linux/Unix/Mac OSX environments. It works as follows:
#
# 1. Checks for and validates the LDC_HOME environment, which must reference
#    the directory where the LDAP Directory Connector is installed. Other
#    directories, including: bin, conf, logs are expected to be direct child
#    directories below LDC_HOME.
#
# 2. If LDC_HOME is not set, it attempts to find it relative to the current
#    working directory or the immediate parent directory.
#
# 3. Constructs the path to the LDAP Directory Connector jar file at:
#    LDC_HOME/libs/onelogin-ldc.jar
#    and ensure it exists.
#
# 4. Constructs the path to the default configuration file at:
#    LDC_HOME/conf/ldc-default.conf
#    and ensure it exists.
#
# 5. Constructs the path to the site-specific configuration file at:
#    LDC_HOME/conf/ldc.conf
#    if exists.
#
# 6. If SECURE_PASSWORD is set, add option for decrypt configuration file.
#
# 7. Constructs command line options.
#
# 8. Constructs Java Virtual Machine configuration options.
#
# 9. If DEBUG is enable, overrides the logback logging config file.
#
# 10. Launches the JVM on the LDAP Directory Connector Main program:
#       if BACKGROUND="true", launches the JVM as a background process.
#       else, launches the JVM as a foreground process.
# -----------------------------------------------------------------------------
#

#--- Uncomment to enable shell debugging
#set -x

#--- Enable Debug
#
#    DEBUG - used to enable/disable DEBUG-level logging by setting
#          a global Property value referencing configuration file:
#          LDC_HOME/conf/logback-debug.xml  (default=false)
#
DEBUG="false"

#--- Flag used to run as a foreground process or a background process.
#
#    BACKGROUND - used by this script to start the Java Virtual Machine as
#          a background process independent from the shell that started it
#          or as a forground process under terminal control.
#
BACKGROUND="false"

#--- The Java JAR file containing LDAP Directory Connector executable code
#
JAR_FILE_NAME="onelogin-ldc.jar"

#--- Check for or set the LDAP Connector Home directory
if [ ! -z "${LDC_HOME}" ]; then
	if [ ! -d ${LDC_HOME} ] ; then
		echo "[FATAL] - the LDC_HOME value (${LDC_HOME}) is not a valid directory path"
		echo "          1. Check the environment value of LDC_HOME"
		echo "          2. Ensure the directory exists, is readable and contains the 'libs' directory"
		echo "             containing the ${JAR_FILE_NAME} file"
		exit 1
	fi
elif [ -f ./libs/${JAR_FILE_NAME} ]; then
	LDC_HOME=.
elif [ -f ../libs/${JAR_FILE_NAME} ]; then
	LDC_HOME=..
else
	echo "[FATAL] - the LDC_HOME value is not set and could not be guessed"
	echo "          1. Set LDC_HOME value to your LDAP Directory Connector installation directory"
	echo "             Example: export LDC_HOME=/usr/local/onelogin-ldc-2.2.12"
	echo "          2. or invoke this script from the directory where you installed the LDAP Directory Connector"
	echo "             Example: cd /usr/local/onelogin-ldc-2.2.12; ./bin/start-ldc.sh"
	echo "          3. or invoke this script from the directory containing this script"
	echo "             Example: cd /usr/local/onelogin-ldc-2.2.12/bin; ./start-ldc.sh"
	exit 1
fi

export LDC_HOME

#--- Check for the executable JAR file
JAR_PATH="${LDC_HOME}/libs/${JAR_FILE_NAME}"
if [ ! -f ${JAR_PATH} ] ; then
	echo "[FATAL] - LDAP Directory Connector jar file not found at: $JAR_PATH"
	echo "          1. Check the value of LDC_HOME (in your environment or in this script)"
	exit 1
fi

#--- Check for ldc-default.conf default configuration File
LDC_DEFAULT_CONFIG_PATH="${LDC_HOME}/conf/ldc-default.conf"
if [ ! -f ${LDC_DEFAULT_CONFIG_PATH} ] ; then
	LDC_DEFAULT_CONFIG_PATH=""
else
	LDC_DEFAULT_CONFIG_PATH="-d ${LDC_DEFAULT_CONFIG_PATH}"
fi

#--- Check for ldc.conf site-specific configuration File
LDC_CONFIG_PATH="${LDC_HOME}/conf/ldc.conf"
if [ ! -f ${LDC_CONFIG_PATH} ] ; then
	echo "[FATAL] - LDAP Directory Connector configuration file not found at: $LDC_CONFIG_PATH"
	echo "          1. Check the value of LDC_HOME (in your environment or in this script)"
	exit 1
else
	LDC_CONFIG_PATH="-f ${LDC_CONFIG_PATH}"
fi

#--- Check for SECURE_PASSWORD variable
LDC_CONFIG_PASSWORD=""
if [ -z "$SECURE_PASSWORD" ] ; then
  echo "[INFO ] - environment variable SECURE_PASSWORD is not defined, encrypted properties are not allowed."
else
  LDC_CONFIG_PASSWORD="-p ${SECURE_PASSWORD}"
fi

#--- Confirm the Java Runtime Environment (JRE) is installed
JVM_MIN_VERSION=8
JVM_PATH=`which java`
if [ -z "${JVM_PATH}" ]; then
	echo "[FATAL] - java command not found"
	echo "          Configure your PATH or install Java version ${JVM_MIN_VERSION} or greater"
	echo "          Download from http://www.oracle.com/technetwork/java/javase/downloads/index.html"
	exit 1
fi

#--- Verify the JRE Version
JVM_VERSION=$(java -version 2>&1 | grep -i version | sed 's/.*version ".*\.\(.*\)\..*"/\1/; 1q')
if [ ${JVM_VERSION} -lt ${JVM_MIN_VERSION} ]; then
	echo "[FATAL] - Java Runtime Environment ${JVM_VERSION} is not supported."
	echo "          Minimum JRE version supported is ${JVM_MIN_VERSION}"
	echo "          Download from http://www.oracle.com/technetwork/java/javase/downloads/index.html"
	exit 1
fi

#--- Set Java Virtual Machine (JVM) configuration options
JVM_OPT=""
JVM_OPT="${JVM_OPT} -server"
JVM_OPT="${JVM_OPT} -Xms1g"
JVM_OPT="${JVM_OPT} -Xmx1g"
JVM_OPT="${JVM_OPT} -XX:+UseG1GC"
JVM_OPT="${JVM_OPT} -XX:MaxGCPauseMillis=500"
JVM_OPT="${JVM_OPT} -XX:InitiatingHeapOccupancyPercent=70"
JVM_OPT="${JVM_OPT} -Djava.util.logging.config.file=${LDC_HOME}/conf/logging.properties"

#--- If DEBUG enabled, use a different logback configuration file
if [ "${DEBUG}" = "true" ]; then
  JVM_OPT="${JVM_OPT} -Dlogback.configurationFile=${LDC_HOME}/conf/logback-debug.xml"
fi

#--- Start the LDAP Directory Connector
if [ "${BACKGROUND}" = "true" ]; then
	if [ ! -d ${LDC_HOME}/logs ]; then
		mkdir -p ${LDC_HOME}/logs
	fi

	# NOTE: the 'nohup' (No Hang Up) command ensures the JVM does not receive
	#       SIGHUP (a hang up signal) that could terminate the program.
	#       This might happen if the login shell in which the LDAP connector is
	#       started, times out and logs out the user. The net effect is that the
	#       LDAP Connector JVM is executed as a 'background' process that survives
	#       the shell that launched it.
	#
	#       stdout - redirected to file: ldc_console.log
	#       stdin - disconnected from the terminal (keyboard) by reading from /dev/null
	#               to avoid SIGHUP to th JVM process
	echo "[INFO] - Starting the OneLogin LDAP Connector as a background process using command:"
	echo "nohup java ${JVM_OPT} -jar ${JAR_PATH} ${LDC_DEFAULT_CONFIG_PATH} ${LDC_CONFIG_PATH} >> ${LDC_HOME}/logs/ldc_console.log 2>&1 < /dev/null &"
	nohup java ${JVM_OPT} -jar ${JAR_PATH} ${LDC_DEFAULT_CONFIG_PATH} ${LDC_CONFIG_PATH} ${LDC_CONFIG_PASSWORD} >> ${LDC_HOME}/logs/ldc_console.log 2>&1 < /dev/null &
else
	echo "[INFO] - Starting the OneLogin LDAP Connector as a foreground process using command:"
	echo "java ${JVM_OPT} -jar ${JAR_PATH} ${LDC_DEFAULT_CONFIG_PATH} ${LDC_CONFIG_PATH}" "$@"
	java ${JVM_OPT} -jar ${JAR_PATH} ${LDC_DEFAULT_CONFIG_PATH} ${LDC_CONFIG_PATH} ${LDC_CONFIG_PASSWORD} "$@"
fi

#
#--- EOF
